from setuptools import setup, find_packages

setup(
    name='bankaccountsystem',
    version='1.1',
    packages=find_packages(exclude=['tests*']),
    license='MIT',
    description='A test python package',
	url='https://github.com/Anakin2009/bankaccountsystem',
    author='Ju, Zhijia',
    author_email='kcjzj0007@gmail.com'
)